# Central Coast aerial lidar processing

Python scripts for cleaning, classifying, and extracting survey profiles from las point clouds.

### 1. Enter input parameters
Input parameters are entered into excel spreadsheets, e.g. `param-files/survey-1.xlsx`. The python scripts take their input in yaml format. The spreadsheets can be converted to yaml by running:

```
python excel_to_yaml.py
```

### 2. Manipulate las data
`las_manipulation.py` does the following to the input las file:
- clip to beach extent
- classify ground points (so vegetation and buildings can be removed later)
- draw a polygon to remove swash zone interference

Example usage:

```
# Process single survey at specific beach
python las_manipulation.py param-files/survey-1-avoca.yaml

# Process single survey at multiple beaches
python las_manipulation.py param-files/survey-1-avoca.yaml param-files/survey-1-pearl.yaml

# Process all surveys at specific beach
python las_manipulation.py param-files/*avoca.yaml

# Process all beaches for specific survey date
python las_manipulation.py param-files/survey-1*.yaml
```

### 3. Check swash clipping mask
The swash clipping mask should be checked visually to ensure it is correct.

### 4. Export results
`las_outputs.py` does the following, based on the outputs of `las_manipulation.py`:
- remove swash zone
- extract elevations from point cloud at profile locations
- complete volume analysis based on Nielsen et al. (1992)
- save figures of profile cross sections
- save raster of ground surface

Example usage:

```
# Process single survey at specific beach
python las_outputs.py param-files/survey-1-avoca.yaml

# Process single survey at multiple beaches
python las_outputs.py param-files/survey-1-avoca.yaml param-files/survey-1-pearl.yaml

# Process all surveys at specific beach
python las_outputs.py param-files/*avoca.yaml

# Process all beaches for specific survey date
python las_outputs.py param-files/survey-1*.yaml
```
